0.1.1 - October 4, 2023
-----------------------

* Update to recent agate, matplotlib and Python versions.

0.1.0 - September 23, 2015
--------------------------

* Use agate 0.10.0 extension API.
* TableSet.bar_chart
* TableSet.scatter_chart
* TableSet.column_chart
* TableSet.line_chart
* Table.bar_chart
* Table.scatter_chart
* Table.column_chart
* Table.line_chart
